pub enum PtxToken {
Show 38 variants
DoubleColon,
Dot,
Comma,
Semicolon,
Colon,
LParen,
RParen,
LBracket,
RBracket,
LBrace,
RBrace,
Plus,
Minus,
Star,
Slash,
LAngle,
RAngle,
Equals,
Percent,
Exclaim,
Pipe,
Ampersand,
Caret,
Tilde,
At,
HexFloatSingle(String),
HexFloatDouble(String),
HexInteger(String),
BinaryInteger(String),
OctalInteger(String),
FloatExponent(String),
Float(String),
DecimalInteger(String),
Register(String),
Identifier(String),
Space,
Newline,
StringLiteral(String),
}Expand description
PTX specification token types for lexical analysis.
This enum represents all token types that can appear in PTX assembly code, including keywords, operators, literals, identifiers, and special markers.
Variants
DoubleColon
Dot
Comma
Semicolon
Colon
LParen
RParen
LBracket
RBracket
LBrace
RBrace
Plus
Minus
Star
Slash
LAngle
RAngle
Equals
Percent
Exclaim
Pipe
Ampersand
Caret
Tilde
At
HexFloatSingle(String)
HexFloatDouble(String)
HexInteger(String)
BinaryInteger(String)
OctalInteger(String)
FloatExponent(String)
Float(String)
DecimalInteger(String)
Register(String)
Identifier(String)
Space
Whitespace tokens emitted by the unparser only (never produced by the lexer).
Newline
StringLiteral(String)
Implementations