pub struct StreamPosition {
pub index: usize,
pub char_offset: usize,
}Expand description
Represents a position in the token stream, including both token index and character offset within a token
Fields
index: usizechar_offset: usizeTrait Implementations
Sourceimpl Clone for StreamPosition
impl Clone for StreamPosition
Sourcefn clone(&self) -> StreamPosition
fn clone(&self) -> StreamPosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StreamPosition
impl Debug for StreamPosition
Sourceimpl PartialEq for StreamPosition
impl PartialEq for StreamPosition
impl Copy for StreamPosition
impl Eq for StreamPosition
impl StructuralPartialEq for StreamPosition