TreeFormatter

Struct TreeFormatter 

pub struct TreeFormatter { /* private fields */ }

Implementations

Source

impl TreeFormatter

pub fn new() -> Self

Create a new TreeFormatter.

pub fn finish(self) -> String

Get the formatted output.

pub fn root(&mut self, content: &str) -> Result

Display a root node (no indentation prefix). Only use this for the very top-level node.

pub fn field(&mut self, is_last: bool, name: &str, value: &str) -> Result

Display a field with a name and value.

pub fn field_with_child<T: TreeDisplay>( &mut self, is_last: bool, name: &str, value: &T, source: &str, ) -> Result

Display a field with a child node that implements TreeDisplay.

pub fn field_option<T: TreeDisplay>( &mut self, is_last: bool, name: &str, value: &Option<T>, source: &str, ) -> Result

Display an optional field.

pub fn field_vec<T: TreeDisplay>( &mut self, is_last: bool, name: &str, items: &[T], source: &str, ) -> Result

Display a vector of items.

pub fn field_array<T: TreeDisplay, const N: usize>( &mut self, is_last: bool, name: &str, items: &[T; N], source: &str, ) -> Result

Display an array of items.

pub fn field_tuple2<T1: TreeDisplay, T2: TreeDisplay>( &mut self, is_last: bool, name: &str, value: &(T1, T2), source: &str, ) -> Result

Display a tuple of 2 items.

pub fn format_raw(&self, span: Span, source: &str) -> String

Extract and format raw source text from a span.

If the text is longer than 40 characters, it will be truncated to show the first 20 and last 20 characters with “…” in the middle. Newlines and other whitespace are normalized to single spaces.